@@ -8,6 +8,14 @@ FULLSCREEN=/usr/bin/gtk_fullscreen_process
 test -x $FULLSCREEN && USE_FULLSCREEN=yes
 
 
+trap bashtrap SIGHUP
+
+bashtrap()
+{
+    kill COPROC_PID
+}
+
+
 if [ x"$USE_FULLSCREEN" = xyes ]; then
     {
         sleep 5
@@ -16,4 +24,6 @@ if [ x"$USE_FULLSCREEN" = xyes ]; then
 fi
 
 #"$@"
-"$@" 2>&1 > /dev/null
\ No newline at end of file
+#"$@" 2>&1 > /dev/null
+coproc "$@" 2>&1 > /dev/null
+wait
\ No newline at end of file
